#ifndef NT2_INCLUDE_CONSTANTS_VALMIN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_VALMIN_HPP_INCLUDED

#include <nt2/constant/include/constants/valmin.hpp>

#endif
